# -*- coding: utf-8 -*-

"""
Chemical information resources

Dictionaries with:
    - Default Tripos SYBYL atom types for amino acids
"""

AA_SYBYL_TYPES = {
    'ACE-C': 'C.2',
    'ACE-CH3': 'C.3',
    'ACE-H1': 'H',
    'ACE-H2': 'H',
    'ACE-H3': 'H',
    'ACE-O': 'O.2',
    'ALA-C': 'C.2',
    'ALA-CA': 'C.3',
    'ALA-CB': 'C.3',
    'ALA-H': 'H',
    'ALA-HA': 'H',
    'ALA-HB1': 'H',
    'ALA-HB2': 'H',
    'ALA-HB3': 'H',
    'ALA-N': 'N.am',
    'ALA-O': 'O.2',
    'ARG-C': 'C.2',
    'ARG-CA': 'C.3',
    'ARG-CB': 'C.3',
    'ARG-CD': 'C.3',
    'ARG-CG': 'C.3',
    'ARG-CZ': 'C.cat',
    'ARG-H': 'H',
    'ARG-HA': 'H',
    'ARG-HB2': 'H',
    'ARG-HB3': 'H',
    'ARG-HD2': 'H',
    'ARG-HD3': 'H',
    'ARG-HE': 'H',
    'ARG-HG2': 'H',
    'ARG-HG3': 'H',
    'ARG-1HH1': 'H',
    'ARG-1HH2': 'H',
    'ARG-2HH1': 'H',
    'ARG-2HH2': 'H',
    'ARG-HH11': 'H',
    'ARG-HH12': 'H',
    'ARG-HH21': 'H',
    'ARG-HH22': 'H',
    'ARG-N': 'N.am',
    'ARG-NE': 'N.pl3',
    'ARG-NH1': 'N.pl3',
    'ARG-NH2': 'N.pl3',
    'ARG-O': 'O.2',
    'ASN-C': 'C.2',
    'ASN-CA': 'C.3',
    'ASN-CB': 'C.3',
    'ASN-CG': 'C.2',
    'ASN-H': 'H',
    'ASN-HA': 'H',
    'ASN-HB2': 'H',
    'ASN-HB3': 'H',
    'ASN-2HD1': 'H',
    'ASN-2HD2': 'H',
    'ASN-HD21': 'H',
    'ASN-HD22': 'H',
    'ASN-N': 'N.am',
    'ASN-ND2': 'N.am',
    'ASN-O': 'O.2',
    'ASN-OD1': 'O.2',
    'ASN-O1': 'O.2',
    'ASN-O2': 'O.2',
    'ASP-C': 'C.2',
    'ASP-CA': 'C.3',
    'ASP-CB': 'C.3',
    'ASP-CG': 'C.2',
    'ASP-H': 'H',
    'ASP-HA': 'H',
    'ASP-HB2': 'H',
    'ASP-HB3': 'H',
    'ASP-N': 'N.am',
    'ASP-O': 'O.2',
    'ASP-OD1': 'O.co2',
    'ASP-OD2': 'O.co2',
    'CYS-C': 'C.2',
    'CYS-CA': 'C.3',
    'CYS-CB': 'C.3',
    'CYS-H': 'H',
    'CYS-HA': 'H',
    'CYS-HB2': 'H',
    'CYS-HB3': 'H',
    'CYS-HG': 'H',
    'CYS-N': 'N.am',
    'CYS-O': 'O.2',
    'CYS-SG': 'S.3',
    'GLN-C': 'C.2',
    'GLN-CA': 'C.3',
    'GLN-CB': 'C.3',
    'GLN-CD': 'C.2',
    'GLN-CG': 'C.3',
    'GLN-H': 'H',
    'GLN-HA': 'H',
    'GLN-HB2': 'H',
    'GLN-HB3': 'H',
    'GLN-HE21': 'H',
    'GLN-HE22': 'H',
    'GLN-HG2': 'H',
    'GLN-HG3': 'H',
    'GLN-N': 'N.am',
    'GLN-NE2': 'N.am',
    'GLN-O': 'O.2',
    'GLN-OE1': 'O.2',
    'GLU-C': 'C.2',
    'GLU-CA': 'C.3',
    'GLU-CB': 'C.3',
    'GLU-CD': 'C.2',
    'GLU-CG': 'C.3',
    'GLU-H': 'H',
    'GLU-HA': 'H',
    'GLU-HB2': 'H',
    'GLU-HB3': 'H',
    'GLU-HG2': 'H',
    'GLU-HG3': 'H',
    'GLU-N': 'N.am',
    'GLU-O': 'O.2',
    'GLU-OE1': 'O.co2',
    'GLU-OE2': 'O.co2',
    'GLY-C': 'C.2',
    'GLY-CA': 'C.3',
    'GLY-H': 'H',
    'GLY-HA2': 'H',
    'GLY-HA3': 'H',
    'GLY-N': 'N.am',
    'GLY-O': 'O.2',
    'HEM-C1A': 'C.ar',
    'HEM-C1B': 'C.ar',
    'HEM-C1C': 'C.ar',
    'HEM-C1D': 'C.ar',
    'HEM-C2A': 'C.ar',
    'HEM-C2B': 'C.ar',
    'HEM-C2C': 'C.ar',
    'HEM-C2D': 'C.ar',
    'HEM-C3A': 'C.ar',
    'HEM-C3B': 'C.ar',
    'HEM-C3C': 'C.ar',
    'HEM-C3D': 'C.ar',
    'HEM-C4A': 'C.ar',
    'HEM-C4B': 'C.ar',
    'HEM-C4C': 'C.ar',
    'HEM-C4D': 'C.ar',
    'HEM-CAA': 'C.3',
    'HEM-CAB': 'C.2',
    'HEM-CAC': 'C.2',
    'HEM-CAD': 'C.3',
    'HEM-CBA': 'C.3',
    'HEM-CBB': 'C.2',
    'HEM-CBC': 'C.2',
    'HEM-CBD': 'C.3',
    'HEM-CGA': 'C.2',
    'HEM-CGD': 'C.2',
    'HEM-CHA': 'C.ar',
    'HEM-CHB': 'C.ar',
    'HEM-CHC': 'C.ar',
    'HEM-CHD': 'C.ar',
    'HEM-CMA': 'C.3',
    'HEM-CMB': 'C.3',
    'HEM-CMC': 'C.3',
    'HEM-CMD': 'C.3',
    'HEM-FE': 'Fe',
    'HEM-HAA1': 'H',
    'HEM-HAA2': 'H',
    'HEM-HAB': 'H',
    'HEM-HAC': 'H',
    'HEM-HAD1': 'H',
    'HEM-HAD2': 'H',
    'HEM-HBA1': 'H',
    'HEM-HBA2': 'H',
    'HEM-HBB1': 'H',
    'HEM-HBB2': 'H',
    'HEM-HBC1': 'H',
    'HEM-HBC2': 'H',
    'HEM-HBD1': 'H',
    'HEM-HBD2': 'H',
    'HEM-HHA': 'H',
    'HEM-HHB': 'H',
    'HEM-HHC': 'H',
    'HEM-HHD': 'H',
    'HEM-HMA1': 'H',
    'HEM-HMA2': 'H',
    'HEM-HMA3': 'H',
    'HEM-HMB1': 'H',
    'HEM-HMB2': 'H',
    'HEM-HMB3': 'H',
    'HEM-HMC1': 'H',
    'HEM-HMC2': 'H',
    'HEM-HMC3': 'H',
    'HEM-HMD1': 'H',
    'HEM-HMD2': 'H',
    'HEM-HMD3': 'H',
    'HEM-NA': 'N.2',
    'HEM-NB': 'N.pl3',
    'HEM-NC': 'N.2',
    'HEM-ND': 'N.pl3',
    'HEM-O1A': 'O.co2',
    'HEM-O1D': 'O.co2',
    'HEM-O2A': 'O.co2',
    'HEM-O2D': 'O.co2',
    'HIS-C': 'C.2',
    'HIS-CA': 'C.3',
    'HIS-CB': 'C.3',
    'HIS-CD2': 'C.2',
    'HIS-CE1': 'C.2',
    'HIS-CG': 'C.2',
    'HIS-H': 'H',
    'HIS-HA': 'H',
    'HIS-HB2': 'H',
    'HIS-HB3': 'H',
    'HIS-HD1': 'H',
    'HIS-HD2': 'H',
    'HIS-HE1': 'H',
    'HIS-HE2': 'H',
    'HIS-N': 'N.am',
    'HIS-ND1': 'N.pl3',
    'HIS-NE2': 'N.2',
    'HIS-O': 'O.2',
    'ILE-C': 'C.2',
    'ILE-CA': 'C.3',
    'ILE-CB': 'C.3',
    'ILE-CD': 'C.3',
    'ILE-CD1': 'C.3',
    'ILE-CG1': 'C.3',
    'ILE-CG2': 'C.3',
    'ILE-H': 'H',
    'ILE-HA': 'H',
    'ILE-HB': 'H',
    'ILE-HD11': 'H',
    'ILE-HD12': 'H',
    'ILE-HD13': 'H',
    'ILE-HG12': 'H',
    'ILE-HG13': 'H',
    'ILE-HG21': 'H',
    'ILE-HG22': 'H',
    'ILE-HG23': 'H',
    'ILE-N': 'N.am',
    'ILE-O': 'O.2',
    'LEU-C': 'C.2',
    'LEU-CA': 'C.3',
    'LEU-CB': 'C.3',
    'LEU-CD1': 'C.3',
    'LEU-CD2': 'C.3',
    'LEU-CG': 'C.3',
    'LEU-H': 'H',
    'LEU-HA': 'H',
    'LEU-HB2': 'H',
    'LEU-HB3': 'H',
    'LEU-HD11': 'H',
    'LEU-HD12': 'H',
    'LEU-HD13': 'H',
    'LEU-HD21': 'H',
    'LEU-HD22': 'H',
    'LEU-HD23': 'H',
    'LEU-HG': 'H',
    'LEU-N': 'N.am',
    'LEU-O': 'O.2',
    'LYS-C': 'C.2',
    'LYS-CA': 'C.3',
    'LYS-CB': 'C.3',
    'LYS-CD': 'C.3',
    'LYS-CE': 'C.3',
    'LYS-CG': 'C.3',
    'LYS-H': 'H',
    'LYS-HA': 'H',
    'LYS-HB2': 'H',
    'LYS-HB3': 'H',
    'LYS-HD2': 'H',
    'LYS-HD3': 'H',
    'LYS-HE2': 'H',
    'LYS-HE3': 'H',
    'LYS-HG2': 'H',
    'LYS-HG3': 'H',
    'LYS-HZ1': 'H',
    'LYS-HZ2': 'H',
    'LYS-HZ3': 'H',
    'LYS-N': 'N.am',
    'LYS-NZ': 'N.4',
    'LYS-O': 'O.2',
    'MET-C': 'C.2',
    'MET-CA': 'C.3',
    'MET-CB': 'C.3',
    'MET-CE': 'C.3',
    'MET-CG': 'C.3',
    'MET-H': 'H',
    'MET-H2': 'H',
    'MET-H3': 'H',
    'MET-HA': 'H',
    'MET-HB2': 'H',
    'MET-HB3': 'H',
    'MET-HE1': 'H',
    'MET-HE2': 'H',
    'MET-HE3': 'H',
    'MET-HG2': 'H',
    'MET-HG3': 'H',
    'MET-N': 'N.am',
    'MET-O': 'O.2',
    'MET-SD': 'S.3',
    'NMA-CA': 'C.3',
    'NMA-H': 'H',
    'NMA-HA1': 'H',
    'NMA-HA2': 'H',
    'NMA-HA3': 'H',
    'NMA-N': 'N.am',
    'PHE-C': 'C.2',
    'PHE-CA': 'C.3',
    'PHE-CB': 'C.3',
    'PHE-CD1': 'C.ar',
    'PHE-CD2': 'C.ar',
    'PHE-CE1': 'C.ar',
    'PHE-CE2': 'C.ar',
    'PHE-CG': 'C.ar',
    'PHE-CZ': 'C.ar',
    'PHE-H': 'H',
    'PHE-HA': 'H',
    'PHE-HB2': 'H',
    'PHE-HB3': 'H',
    'PHE-HD1': 'H',
    'PHE-HD2': 'H',
    'PHE-HE1': 'H',
    'PHE-HE2': 'H',
    'PHE-HZ': 'H',
    'PHE-N': 'N.am',
    'PHE-O': 'O.2',
    'PRO-C': 'C.2',
    'PRO-CA': 'C.3',
    'PRO-CB': 'C.3',
    'PRO-CD': 'C.3',
    'PRO-CG': 'C.3',
    'PRO-HA': 'H',
    'PRO-HB2': 'H',
    'PRO-HB3': 'H',
    'PRO-HD2': 'H',
    'PRO-HD3': 'H',
    'PRO-HG2': 'H',
    'PRO-HG3': 'H',
    'PRO-N': 'N.am',
    'PRO-O': 'O.2',
    'SER-C': 'C.2',
    'SER-CA': 'C.3',
    'SER-CB': 'C.3',
    'SER-H': 'H',
    'SER-HA': 'H',
    'SER-HB2': 'H',
    'SER-HB3': 'H',
    'SER-HG': 'H',
    'SER-N': 'N.am',
    'SER-O': 'O.2',
    'SER-OG': 'O.3',
    'THR-C': 'C.2',
    'THR-CA': 'C.3',
    'THR-CB': 'C.3',
    'THR-CG2': 'C.3',
    'THR-H': 'H',
    'THR-HA': 'H',
    'THR-HB': 'H',
    'THR-HG1': 'H',
    'THR-HG21': 'H',
    'THR-HG22': 'H',
    'THR-HG23': 'H',
    'THR-N': 'N.am',
    'THR-O': 'O.2',
    'THR-OG1': 'O.3',
    'TRP-C': 'C.2',
    'TRP-CA': 'C.3',
    'TRP-CB': 'C.3',
    'TRP-CD1': 'C.ar',
    'TRP-CD2': 'C.ar',
    'TRP-CE2': 'C.ar',
    'TRP-CE3': 'C.ar',
    'TRP-CG': 'C.ar',
    'TRP-CH2': 'C.ar',
    'TRP-CZ2': 'C.ar',
    'TRP-CZ3': 'C.ar',
    'TRP-H': 'H',
    'TRP-HA': 'H',
    'TRP-HB2': 'H',
    'TRP-HB3': 'H',
    'TRP-HD1': 'H',
    'TRP-HE1': 'H',
    'TRP-HE3': 'H',
    'TRP-HH2': 'H',
    'TRP-HZ2': 'H',
    'TRP-HZ3': 'H',
    'TRP-N': 'N.am',
    'TRP-NE1': 'N.pl3',
    'TRP-O': 'O.2',
    'TYR-C': 'C.2',
    'TYR-CA': 'C.3',
    'TYR-CB': 'C.3',
    'TYR-CD1': 'C.ar',
    'TYR-CD2': 'C.ar',
    'TYR-CE1': 'C.ar',
    'TYR-CE2': 'C.ar',
    'TYR-CG': 'C.ar',
    'TYR-CZ': 'C.ar',
    'TYR-H': 'H',
    'TYR-HA': 'H',
    'TYR-HB2': 'H',
    'TYR-HB3': 'H',
    'TYR-HD1': 'H',
    'TYR-HD2': 'H',
    'TYR-HE1': 'H',
    'TYR-HE2': 'H',
    'TYR-HH': 'H',
    'TYR-N': 'N.am',
    'TYR-O': 'O.2',
    'TYR-OH': 'O.3',
    'VAL-C': 'C.2',
    'VAL-CA': 'C.3',
    'VAL-CB': 'C.3',
    'VAL-CG1': 'C.3',
    'VAL-CG2': 'C.3',
    'VAL-H': 'H',
    'VAL-HA': 'H',
    'VAL-HB': 'H',
    'VAL-HG11': 'H',
    'VAL-HG12': 'H',
    'VAL-HG13': 'H',
    'VAL-HG21': 'H',
    'VAL-HG22': 'H',
    'VAL-HG23': 'H',
    'VAL-N': 'N.am',
    'VAL-O': 'O.2'
}
